# pymongo-curd



## 主要功能

- Document(一级文档)
    - get
    - get_one
    - get_by_id
    - post
    - post_and_chick_repeat
    - put
    - put_and_chick_repeat

- SecDocument(二级文档)
    - post_sec
    - post_sec_and_chick_repeat
    - put_sec
    - put_sec_and_chick_repeat
    - delete_sec

